@@ -136,7 +136,7 @@ public class LoginPageByFormActionReturningStringStep extends AbstractStep<Strin
                if (matcher.find()){
                    output = matcher.group(0);
                } else {
-                   LOG.error("Page that does not have the String to imply a successful login : " + pageAfterLogin.getWebResponse().getContentAsString());
+                   LOG.debug("Page that does not have the String to imply a successful login : " + pageAfterLogin.getWebResponse().getContentAsString());
                    if (debuggingEnabled){
                        openPageInBrowser(pageAfterLogin);
                    }
