@@ -58,6 +58,7 @@ import java.lang.reflect.TypeVariable;
 import com.gargoylesoftware.htmlunit.Page;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Streams;
 import com.openexchange.subscribe.crawler.Workflow;
 
 public abstract class AbstractStep<O,I> implements Step<O,I>{
@@ -176,13 +177,8 @@ public abstract class AbstractStep<O,I> implements Step<O,I>{
           //windows: iexplore http://www.example.com
         } catch (IOException e) {
             e.printStackTrace();
-        }
-        finally {
-          try {
-            output.close();
-        } catch (IOException e) {
-            e.printStackTrace();
-        }
+        } finally {
+            Streams.close(output);
         }
     }
 
