@@ -68,7 +68,13 @@ public enum OXMFSubscriptionErrorMessage implements OXExceptionCode {
     IOException(CATEGORY_SERVICE_DOWN, 3, OXMFErrorStrings.IOException_HELP, OXMFErrorStrings.IOException),
     HttpException(CATEGORY_SERVICE_DOWN, 4, OXMFErrorStrings.HttpException_HELP, OXMFErrorStrings.HttpException),
     CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES(CATEGORY_ERROR, 5, OXMFErrorStrings.CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES_HELP, OXMFErrorStrings.CAN_ONLY_POST_TO_EXTERNAL_SUBSCRIPTION_SOURCES),
-    ERROR_LOADING_SUBSCRIPTION(CATEGORY_SERVICE_DOWN, 6, OXMFErrorStrings.ERROR_LOADING_SUBSCRIPTION_HELP, OXMFErrorStrings.ERROR_LOADING_SUBSCRIPTION), ;
+    ERROR_LOADING_SUBSCRIPTION(CATEGORY_SERVICE_DOWN, 6, OXMFErrorStrings.ERROR_LOADING_SUBSCRIPTION_HELP, OXMFErrorStrings.ERROR_LOADING_SUBSCRIPTION),
+    /**
+     * The string cannot be parsed to a valid URL.
+     */
+    INVALID_URL(CATEGORY_USER_INPUT, 7, OXMFErrorStrings.INVALID_URL, OXMFErrorStrings.INVALID_URL),
+    
+    ;
 
     private Category category;
 
